@@ -84,6 +84,9 @@ SERVICE_VERSIONS = {
     "cdwpg": [
         "2020-12-30"
     ],
+    "cdz": [
+        "2022-11-23"
+    ],
     "cfg": [
         "2021-08-20"
     ],
@@ -255,6 +258,9 @@ SERVICE_VERSIONS = {
     "mdp": [
         "2020-05-27"
     ],
+    "message": [
+        "2018-12-25"
+    ],
     "mongodb": [
         "2019-07-25"
     ],
@@ -286,6 +292,9 @@ SERVICE_VERSIONS = {
     "pts": [
         "2021-07-28"
     ],
+    "quota": [
+        "2024-12-04"
+    ],
     "rce": [
         "2020-11-03"
     ],
@@ -407,7 +416,8 @@ SERVICE_VERSIONS = {
         "2018-01-25"
     ],
     "wedata": [
-        "2021-08-20"
+        "2021-08-20",
+        "2025-08-06"
     ],
     "yunjing": [
         "2018-02-28"
